/*******************************************************************************
* File Name: Clock_Sync.h
* Version 1.70
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_CLOCK_Clock_Sync_H)
#define CY_CLOCK_Clock_Sync_H

#include <cytypes.h>
#include <cyfitter.h>

/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v1_70 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

/***************************************
*        Function Prototypes
***************************************/

void Clock_Sync_Start(void) ;
void Clock_Sync_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void Clock_Sync_StopBlock(void) ;
#endif

void Clock_Sync_StandbyPower(uint8 state) ;
void Clock_Sync_SetDividerRegister(uint16 clkDivider, uint8 reset) ;
uint16 Clock_Sync_GetDividerRegister(void) ;
void Clock_Sync_SetModeRegister(uint8 modeBitMask) ;
void Clock_Sync_ClearModeRegister(uint8 modeBitMask) ;
uint8 Clock_Sync_GetModeRegister(void) ;
void Clock_Sync_SetSourceRegister(uint8 clkSource) ;
uint8 Clock_Sync_GetSourceRegister(void) ;
#if defined(Clock_Sync__CFG3)
void Clock_Sync_SetPhaseRegister(uint8 clkPhase) ;
uint8 Clock_Sync_GetPhaseRegister(void) ;
#endif

#define Clock_Sync_Enable()                       Clock_Sync_Start()
#define Clock_Sync_Disable()                      Clock_Sync_Stop()
#define Clock_Sync_SetDivider(clkDivider)         Clock_Sync_SetDividerRegister(clkDivider, 1)
#define Clock_Sync_SetDividerValue(clkDivider)    Clock_Sync_SetDividerRegister((clkDivider) - 1, 1)
#define Clock_Sync_SetMode(clkMode)               Clock_Sync_SetModeRegister(clkMode)
#define Clock_Sync_SetSource(clkSource)           Clock_Sync_SetSourceRegister(clkSource)
#if defined(Clock_Sync__CFG3)
#define Clock_Sync_SetPhase(clkPhase)             Clock_Sync_SetPhaseRegister(clkPhase)
#define Clock_Sync_SetPhaseValue(clkPhase)        Clock_Sync_SetPhaseRegister((clkPhase) + 1)
#endif


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define Clock_Sync_CLKEN              (* (reg8 *) Clock_Sync__PM_ACT_CFG)
#define Clock_Sync_CLKEN_PTR          ((reg8 *) Clock_Sync__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define Clock_Sync_CLKSTBY            (* (reg8 *) Clock_Sync__PM_STBY_CFG)
#define Clock_Sync_CLKSTBY_PTR        ((reg8 *) Clock_Sync__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define Clock_Sync_DIV_LSB            (* (reg8 *) Clock_Sync__CFG0)
#define Clock_Sync_DIV_LSB_PTR        ((reg8 *) Clock_Sync__CFG0)
#define Clock_Sync_DIV_PTR            ((reg16 *) Clock_Sync__CFG0)

/* Clock MSB divider configuration register. */
#define Clock_Sync_DIV_MSB            (* (reg8 *) Clock_Sync__CFG1)
#define Clock_Sync_DIV_MSB_PTR        ((reg8 *) Clock_Sync__CFG1)

/* Mode and source configuration register */
#define Clock_Sync_MOD_SRC            (* (reg8 *) Clock_Sync__CFG2)
#define Clock_Sync_MOD_SRC_PTR        ((reg8 *) Clock_Sync__CFG2)

#if defined(Clock_Sync__CFG3)
/* Analog clock phase configuration register */
#define Clock_Sync_PHASE              (* (reg8 *) Clock_Sync__CFG3)
#define Clock_Sync_PHASE_PTR          ((reg8 *) Clock_Sync__CFG3)
#endif


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define Clock_Sync_CLKEN_MASK         Clock_Sync__PM_ACT_MSK
#define Clock_Sync_CLKSTBY_MASK       Clock_Sync__PM_STBY_MSK

/* CFG2 field masks */
#define Clock_Sync_SRC_SEL_MSK        Clock_Sync__CFG2_SRC_SEL_MASK
#define Clock_Sync_MODE_MASK          (~(Clock_Sync_SRC_SEL_MSK))

#if defined(Clock_Sync__CFG3)
/* CFG3 phase mask */
#define Clock_Sync_PHASE_MASK         Clock_Sync__CFG3_PHASE_DLY_MASK
#endif

#endif /* CY_CLOCK_Clock_Sync_H */


/* [] END OF FILE */
