/*******************************************************************************
* File Name: Comp_Sync.c
* Version 1.90
*
* Description:
*  This file contains the function prototypes and constants used in
*  the Analog Comparator User Module.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_COMP_Comp_Sync_H) 
#define CY_COMP_Comp_Sync_H

#include "cytypes.h"
#include "CyLib.h"
#include "cyfitter.h" 


#define Comp_Sync_RECALMODE 0u

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component Comp_v1_90 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*       Type defines
***************************************/

/* Sleep Mode API Support */
typedef struct Comp_Sync_backupStruct
{
    uint8 enableState;
   /* uint8 compCRReg; */
}Comp_Sync_backupStruct;

#if (CY_PSOC5A)
    /* Stop API changes for PSoC5A */
    typedef struct _Comp_Sync_lowPowerBackupStruct
    {
        uint8 compCRReg;
    }   Comp_Sync_LOWPOWER_BACKUP_STRUCT;
#endif /* CY_PSOC5A */


/**************************************
*        Function Prototypes 
**************************************/

void    Comp_Sync_Start(void)                  ;
void    Comp_Sync_Stop(void)                   ;
void    Comp_Sync_SetSpeed(uint8 speed)        ;
uint8   Comp_Sync_GetCompare(void)             ;
uint16  Comp_Sync_ZeroCal(void)                ;
void    Comp_Sync_LoadTrim(uint16 trimVal)     ;
void Comp_Sync_Init(void)                      ; 
void Comp_Sync_Enable(void)                    ;
void Comp_Sync_trimAdjust(uint8 nibble)        ;
void Comp_Sync_SaveConfig(void)                ;
void Comp_Sync_RestoreConfig(void)             ;
void Comp_Sync_Sleep(void)                     ;
void Comp_Sync_Wakeup(void)                    ;
/* Below APIs are valid only for PSoC3, PSoC5LP silicons.*/
#if (CY_PSOC3 || CY_PSOC5LP) 
    void Comp_Sync_PwrDwnOverrideEnable(void)  ;
    void Comp_Sync_PwrDwnOverrideDisable(void) ;
#endif /* CY_PSOC3 || CY_PSOC5LP */


/**************************************
*           API Constants        
**************************************/

/* Power constants for SetSpeed() function */
#define Comp_Sync_SLOWSPEED   0x00u
#define Comp_Sync_HIGHSPEED   0x01u
#define Comp_Sync_LOWPOWER    0x02u


/***************************************
*         Trim Locations               
****************************************/

/* High speed trim values */
#define Comp_Sync_HS_TRIM_TR0        (CY_GET_XTND_REG8(Comp_Sync_ctComp__TRIM__TR0_HS))

#if (CY_PSOC3 || CY_PSOC5LP)
    #define Comp_Sync_HS_TRIM_TR1    (CY_GET_XTND_REG8(Comp_Sync_ctComp__TRIM__TR1_HS))
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

/* Low speed trim values */
#define Comp_Sync_LS_TRIM_TR0        (CY_GET_XTND_REG8(Comp_Sync_ctComp__TRIM__TR0 + 1))

#if (CY_PSOC3 || CY_PSOC5LP)
    #define Comp_Sync_LS_TRIM_TR1    (CY_GET_XTND_REG8(Comp_Sync_ctComp__TRIM__TR1 + 1))
#endif /* CY_PSOC3 || CY_PSOC5LP */


/**************************************
*           Parameter Defaults        
**************************************/

#define Comp_Sync_DEFAULT_SPEED       1u 
#define Comp_Sync_DEFAULT_HYSTERESIS  0u
#define Comp_Sync_DEFAULT_POLARITY    1u
#define Comp_Sync_DEFAULT_BYPASS_SYNC 1u
#define Comp_Sync_DEFAULT_PWRDWN_OVRD 0u


/**************************************
*             Registers        
**************************************/

#define Comp_Sync_CR      (* (reg8 *) Comp_Sync_ctComp__CR )   /* Config register   */
#define Comp_Sync_CR_PTR  (  (reg8 *) Comp_Sync_ctComp__CR )
#define Comp_Sync_CLK     (* (reg8 *) Comp_Sync_ctComp__CLK )  /* Comp clock control register */
#define Comp_Sync_CLK_PTR (  (reg8 *) Comp_Sync_ctComp__CLK )
#define Comp_Sync_SW0     (* (reg8 *) Comp_Sync_ctComp__SW0 )  /* Routing registers */
#define Comp_Sync_SW0_PTR (  (reg8 *) Comp_Sync_ctComp__SW0 )
#define Comp_Sync_SW2     (* (reg8 *) Comp_Sync_ctComp__SW2 )
#define Comp_Sync_SW2_PTR (  (reg8 *) Comp_Sync_ctComp__SW2 )
#define Comp_Sync_SW3     (* (reg8 *) Comp_Sync_ctComp__SW3 )
#define Comp_Sync_SW3_PTR (  (reg8 *) Comp_Sync_ctComp__SW3 )
#define Comp_Sync_SW4     (* (reg8 *) Comp_Sync_ctComp__SW4 )
#define Comp_Sync_SW4_PTR (  (reg8 *) Comp_Sync_ctComp__SW4 )
#define Comp_Sync_SW6     (* (reg8 *) Comp_Sync_ctComp__SW6 )
#define Comp_Sync_SW6_PTR (  (reg8 *) Comp_Sync_ctComp__SW6 )

/* Trim registers */
/* PSoC5A */
#if (CY_PSOC5A)
    #define Comp_Sync_TR      (* (reg8 *) Comp_Sync_ctComp__TR )   /* Trim registers */
    #define Comp_Sync_TR_PTR  (  (reg8 *) Comp_Sync_ctComp__TR )
#endif /* CY_PSOC5A */

/* PSoC3, PSoC5LP or later */
#if (CY_PSOC3 || CY_PSOC5LP) 
    #define Comp_Sync_TR0         (* (reg8 *) Comp_Sync_ctComp__TR0 ) /* Trim register for P-type load */
    #define Comp_Sync_TR0_PTR     (  (reg8 *) Comp_Sync_ctComp__TR0 ) 
    #define Comp_Sync_TR1         (* (reg8 *) Comp_Sync_ctComp__TR1 ) /* Trim register for N-type load */
    #define Comp_Sync_TR1_PTR     (  (reg8 *) Comp_Sync_ctComp__TR1 ) 
#endif /* CY_PSOC3 || CY_PSOC5LP */

#define Comp_Sync_WRK             (* (reg8 *) Comp_Sync_ctComp__WRK )  /* Working register - output */
#define Comp_Sync_WRK_PTR         (  (reg8 *) Comp_Sync_ctComp__WRK )
#define Comp_Sync_PWRMGR          (* (reg8 *) Comp_Sync_ctComp__PM_ACT_CFG )  /* Active Power manager */
#define Comp_Sync_PWRMGR_PTR      ( (reg8 *) Comp_Sync_ctComp__PM_ACT_CFG )
#define Comp_Sync_STBY_PWRMGR     (* (reg8 *) Comp_Sync_ctComp__PM_STBY_CFG )  /* Standby Power manager */
#define Comp_Sync_STBY_PWRMGR_PTR ( (reg8 *) Comp_Sync_ctComp__PM_STBY_CFG )


/**************************************
*       Register Constants        
**************************************/

/* CR (Comp Control Register)             */
#define Comp_Sync_CFG_MODE_MASK  0x78u
#define Comp_Sync_FILTER_ON      0x40u
#define Comp_Sync_HYST_OFF       0x20u
#define Comp_Sync_CAL_ON         0x10u
#define Comp_Sync_MX_AO          0x08u
#define Comp_Sync_PWRDWN_OVRD    0x04u

#define Comp_Sync_PWR_MODE_SHIFT 0x00u
#define Comp_Sync_PWR_MODE_MASK  (0x03u << Comp_Sync_PWR_MODE_SHIFT)
#define Comp_Sync_PWR_MODE_SLOW  (0x00u << Comp_Sync_PWR_MODE_SHIFT)
#define Comp_Sync_PWR_MODE_FAST  (0x01u << Comp_Sync_PWR_MODE_SHIFT)
#define Comp_Sync_PWR_MODE_ULOW  (0x02u << Comp_Sync_PWR_MODE_SHIFT)

/* CLK (Comp Clock Control Register)      */
#define Comp_Sync_BYPASS_SYNC    0x10u
#define Comp_Sync_SYNC_CLK_EN    0x08u
#define Comp_Sync_SYNCCLK_MASK   (Comp_Sync_BYPASS_SYNC | Comp_Sync_SYNC_CLK_EN)

/* SW3 Routing Register definitions */
#define Comp_Sync_CMP_SW3_INPCTL_MASK    0x09u   /* SW3 bits for inP routing control */

/* TR (Comp Trim Register)     */
#define Comp_Sync_DEFAULT_CMP_TRIM  0x00u

/* PSoC5A */
#if (CY_PSOC5A)
    #define Comp_Sync_CMP_TRIM1_DIR  0x08u   /* Trim direction for N-type load for offset calibration */
    #define Comp_Sync_CMP_TRIM1_MASK 0x07u   /* Trim for N-type load for offset calibration */
    #define Comp_Sync_CMP_TRIM2_DIR  0x80u   /* Trim direction for P-type load for offset calibration */
    #define Comp_Sync_CMP_TRIM2_MASK 0x70u   /* Trim for P-type load for offset calibration */
#endif /* CY_PSOC5A */

/* PSoC3, PSoC5LP or later */
#if (CY_PSOC3 || CY_PSOC5LP)
    #define Comp_Sync_CMP_TR0_DIR 0x10u    /* Trim direction for N-type load for offset calibration */
    #define Comp_Sync_CMP_TR0_MASK 0x0Fu   /* Trim for N-type load for offset calibration */
    #define Comp_Sync_CMP_TR1_DIR 0x10u    /* Trim direction for P-type load for offset calibration */
    #define Comp_Sync_CMP_TR1_MASK 0x07u   /* Trim for P-type load for offset calibration */ 
#endif /* CY_PSOC3 || CY_PSOC5LP */


/* WRK (Comp output working register)     */ 
#define Comp_Sync_CMP_OUT_MASK   Comp_Sync_ctComp__WRK_MASK /* Specific comparator out mask */

/* PM_ACT_CFG7 (Active Power Mode CFG Register)     */ 
#define Comp_Sync_ACT_PWR_EN     Comp_Sync_ctComp__PM_ACT_MSK /* Power enable mask */

/* PM_STBY_CFG7 (Standby Power Mode CFG Register)     */ 
#define Comp_Sync_STBY_PWR_EN     Comp_Sync_ctComp__PM_STBY_MSK /* Standby Power enable mask */

#if (CY_PSOC5A)
    /* For stop API changes mask to make the COMP register CR to 0X00  */
    #define Comp_Sync_COMP_REG_CLR             (0x00u)
#endif /* CY_PSOC5A */

#endif /* CY_COMP_Comp_Sync_H */


/* [] END OF FILE */
