/*******************************************************************************
* File Name: DigIn.c  
* Version 1.70
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "DigIn.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 DigIn__PORT == 15 && (DigIn__MASK & 0xC0))

/*******************************************************************************
* Function Name: DigIn_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void DigIn_Write(uint8 value) 
{
    uint8 staticBits = DigIn_DR & ~DigIn_MASK;
    DigIn_DR = staticBits | ((value << DigIn_SHIFT) & DigIn_MASK);
}


/*******************************************************************************
* Function Name: DigIn_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void DigIn_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(DigIn_0, mode);
	CyPins_SetPinDriveMode(DigIn_1, mode);
	CyPins_SetPinDriveMode(DigIn_2, mode);
	CyPins_SetPinDriveMode(DigIn_3, mode);
	CyPins_SetPinDriveMode(DigIn_4, mode);
	CyPins_SetPinDriveMode(DigIn_5, mode);
	CyPins_SetPinDriveMode(DigIn_6, mode);
	CyPins_SetPinDriveMode(DigIn_7, mode);
}


/*******************************************************************************
* Function Name: DigIn_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro DigIn_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 DigIn_Read(void) 
{
    return (DigIn_PS & DigIn_MASK) >> DigIn_SHIFT;
}


/*******************************************************************************
* Function Name: DigIn_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 DigIn_ReadDataReg(void) 
{
    return (DigIn_DR & DigIn_MASK) >> DigIn_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(DigIn_INTSTAT) 

    /*******************************************************************************
    * Function Name: DigIn_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 DigIn_ClearInterrupt(void) 
    {
        return (DigIn_INTSTAT & DigIn_MASK) >> DigIn_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif
/* [] END OF FILE */ 
