/*******************************************************************************
* File Name: GLCD_Control.c  
* Version 1.70
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "GLCD_Control.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 GLCD_Control__PORT == 15 && (GLCD_Control__MASK & 0xC0))

/*******************************************************************************
* Function Name: GLCD_Control_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void GLCD_Control_Write(uint8 value) 
{
    uint8 staticBits = GLCD_Control_DR & ~GLCD_Control_MASK;
    GLCD_Control_DR = staticBits | ((value << GLCD_Control_SHIFT) & GLCD_Control_MASK);
}


/*******************************************************************************
* Function Name: GLCD_Control_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void GLCD_Control_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(GLCD_Control_0, mode);
	CyPins_SetPinDriveMode(GLCD_Control_1, mode);
	CyPins_SetPinDriveMode(GLCD_Control_2, mode);
	CyPins_SetPinDriveMode(GLCD_Control_3, mode);
}


/*******************************************************************************
* Function Name: GLCD_Control_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro GLCD_Control_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 GLCD_Control_Read(void) 
{
    return (GLCD_Control_PS & GLCD_Control_MASK) >> GLCD_Control_SHIFT;
}


/*******************************************************************************
* Function Name: GLCD_Control_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 GLCD_Control_ReadDataReg(void) 
{
    return (GLCD_Control_DR & GLCD_Control_MASK) >> GLCD_Control_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(GLCD_Control_INTSTAT) 

    /*******************************************************************************
    * Function Name: GLCD_Control_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 GLCD_Control_ClearInterrupt(void) 
    {
        return (GLCD_Control_INTSTAT & GLCD_Control_MASK) >> GLCD_Control_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif
/* [] END OF FILE */ 
