/*******************************************************************************
* File Name: PWM_Dig_PM.c
* Version 2.0
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/
#include "cytypes.h"
#include "PWM_Dig.h"

static PWM_Dig_backupStruct PWM_Dig_backup;


/*******************************************************************************
* Function Name: PWM_Dig_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  PWM_Dig_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PWM_Dig_SaveConfig(void)
{
    
    #if(!PWM_Dig_UsingFixedFunction)
        #if (PWM_Dig_PSOC3_ES2 || PWM_Dig_PSOC5_ES1)
            PWM_Dig_backup.PWMUdb = PWM_Dig_ReadCounter();
            PWM_Dig_backup.PWMPeriod = PWM_Dig_ReadPeriod();
            #if (PWM_Dig_UseStatus)
				PWM_Dig_backup.InterruptMaskValue = PWM_Dig_STATUS_MASK;
            #endif
			
            #if(PWM_Dig_UseOneCompareMode)
                PWM_Dig_backup.PWMCompareValue = PWM_Dig_ReadCompare();
            #else
                PWM_Dig_backup.PWMCompareValue1 = PWM_Dig_ReadCompare1();
                PWM_Dig_backup.PWMCompareValue2 = PWM_Dig_ReadCompare2();
            #endif
            
           #if(PWM_Dig_DeadBandUsed)
                PWM_Dig_backup.PWMdeadBandValue = PWM_Dig_ReadDeadTime();
            #endif
          
            #if ( PWM_Dig_KillModeMinTime)
                PWM_Dig_backup.PWMKillCounterPeriod = PWM_Dig_ReadKillTime();
            #endif
        #endif
        
        #if (PWM_Dig_PSOC3_ES3 || PWM_Dig_PSOC5_ES2)
            PWM_Dig_backup.PWMUdb = PWM_Dig_ReadCounter();
            #if (PWM_Dig_UseStatus)
				PWM_Dig_backup.InterruptMaskValue = PWM_Dig_STATUS_MASK;
			#endif
            
            #if(PWM_Dig_DeadBandMode == PWM_Dig__B_PWM__DBM_256_CLOCKS || PWM_Dig_DeadBandMode == PWM_Dig__B_PWM__DBM_2_4_CLOCKS)
                PWM_Dig_backup.PWMdeadBandValue = PWM_Dig_ReadDeadTime();
            #endif
            
            #if(PWM_Dig_KillModeMinTime)
                 PWM_Dig_backup.PWMKillCounterPeriod = PWM_Dig_ReadKillTime();
            #endif
        #endif
        
        #if(PWM_Dig_UseControl)
            PWM_Dig_backup.PWMControlRegister = PWM_Dig_ReadControlRegister();
        #endif
    #endif  
}


/*******************************************************************************
* Function Name: PWM_Dig_RestoreConfig
********************************************************************************
* 
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  PWM_Dig_backup:  Variables of this global structure are used to restore 
*  the values of non retention registers on wakeup from sleep mode.
*
* Reentrant:
*  Yes.
*
*******************************************************************************/
void PWM_Dig_RestoreConfig(void) 
{
        #if(!PWM_Dig_UsingFixedFunction)
            #if (PWM_Dig_PSOC3_ES2 || PWM_Dig_PSOC5_ES1)
                PWM_Dig_WriteCounter(PWM_Dig_backup.PWMUdb);
                PWM_Dig_WritePeriod(PWM_Dig_backup.PWMPeriod);
                #if (PWM_Dig_UseStatus)
					PWM_Dig_STATUS_MASK = PWM_Dig_backup.InterruptMaskValue;
                #endif
				
                #if(PWM_Dig_UseOneCompareMode)
                    PWM_Dig_WriteCompare(PWM_Dig_backup.PWMCompareValue);
                #else
                    PWM_Dig_WriteCompare1(PWM_Dig_backup.PWMCompareValue1);
                    PWM_Dig_WriteCompare2(PWM_Dig_backup.PWMCompareValue2);
                #endif
                
               #if(PWM_Dig_DeadBandMode == PWM_Dig__B_PWM__DBM_256_CLOCKS || PWM_Dig_DeadBandMode == PWM_Dig__B_PWM__DBM_2_4_CLOCKS)
                    PWM_Dig_WriteDeadTime(PWM_Dig_backup.PWMdeadBandValue);
                #endif
            
                #if ( PWM_Dig_KillModeMinTime)
                    PWM_Dig_WriteKillTime(PWM_Dig_backup.PWMKillCounterPeriod);
                #endif
            #endif
            
            #if (PWM_Dig_PSOC3_ES3 || PWM_Dig_PSOC5_ES2)
                PWM_Dig_WriteCounter(PWM_Dig_backup.PWMUdb);
                #if (PWM_Dig_UseStatus)
                    PWM_Dig_STATUS_MASK = PWM_Dig_backup.InterruptMaskValue;
                #endif
                
                #if(PWM_Dig_DeadBandMode == PWM_Dig__B_PWM__DBM_256_CLOCKS || PWM_Dig_DeadBandMode == PWM_Dig__B_PWM__DBM_2_4_CLOCKS)
                    PWM_Dig_WriteDeadTime(PWM_Dig_backup.PWMdeadBandValue);
                #endif
                
                #if(PWM_Dig_KillModeMinTime)
                    PWM_Dig_WriteKillTime(PWM_Dig_backup.PWMKillCounterPeriod);
                #endif
            #endif
            
            #if(PWM_Dig_UseControl)
                PWM_Dig_WriteControlRegister(PWM_Dig_backup.PWMControlRegister); 
            #endif
        #endif  
    }


/*******************************************************************************
* Function Name: PWM_Dig_Sleep
********************************************************************************
* 
* Summary:
*  Disables block's operation and saves the user configuration. Should be called 
*  just prior to entering sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  PWM_Dig_backup.PWMEnableState:  Is modified depending on the enable state
*  of the block before entering sleep mode.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PWM_Dig_Sleep(void)
{
    #if(PWM_Dig_UseControl)
        if(PWM_Dig_CTRL_ENABLE == (PWM_Dig_CONTROL & PWM_Dig_CTRL_ENABLE))
        {
            /*Component is enabled */
            PWM_Dig_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            PWM_Dig_backup.PWMEnableState = 0u;
        }
    #endif
    /* Stop component */
    PWM_Dig_Stop();
    
    /* Save registers configuration */
    PWM_Dig_SaveConfig();
}


/*******************************************************************************
* Function Name: PWM_Dig_Wakeup
********************************************************************************
* 
* Summary:
*  Restores and enables the user configuration. Should be called just after 
*  awaking from sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  PWM_Dig_backup.pwmEnable:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void PWM_Dig_Wakeup(void) 
{
     /* Restore registers values */
    PWM_Dig_RestoreConfig();
    
    if(PWM_Dig_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        PWM_Dig_Enable();
    } /* Do nothing if component's block was disabled before */
    
}

/* [] END OF FILE */
