/*******************************************************************************
* File Name: Sync_Clock.h
* Version 1.70
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_CLOCK_Sync_Clock_H)
#define CY_CLOCK_Sync_Clock_H

#include <cytypes.h>
#include <cyfitter.h>

/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v1_70 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

/***************************************
*        Function Prototypes
***************************************/

void Sync_Clock_Start(void) ;
void Sync_Clock_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void Sync_Clock_StopBlock(void) ;
#endif

void Sync_Clock_StandbyPower(uint8 state) ;
void Sync_Clock_SetDividerRegister(uint16 clkDivider, uint8 reset) ;
uint16 Sync_Clock_GetDividerRegister(void) ;
void Sync_Clock_SetModeRegister(uint8 modeBitMask) ;
void Sync_Clock_ClearModeRegister(uint8 modeBitMask) ;
uint8 Sync_Clock_GetModeRegister(void) ;
void Sync_Clock_SetSourceRegister(uint8 clkSource) ;
uint8 Sync_Clock_GetSourceRegister(void) ;
#if defined(Sync_Clock__CFG3)
void Sync_Clock_SetPhaseRegister(uint8 clkPhase) ;
uint8 Sync_Clock_GetPhaseRegister(void) ;
#endif

#define Sync_Clock_Enable()                       Sync_Clock_Start()
#define Sync_Clock_Disable()                      Sync_Clock_Stop()
#define Sync_Clock_SetDivider(clkDivider)         Sync_Clock_SetDividerRegister(clkDivider, 1)
#define Sync_Clock_SetDividerValue(clkDivider)    Sync_Clock_SetDividerRegister((clkDivider) - 1, 1)
#define Sync_Clock_SetMode(clkMode)               Sync_Clock_SetModeRegister(clkMode)
#define Sync_Clock_SetSource(clkSource)           Sync_Clock_SetSourceRegister(clkSource)
#if defined(Sync_Clock__CFG3)
#define Sync_Clock_SetPhase(clkPhase)             Sync_Clock_SetPhaseRegister(clkPhase)
#define Sync_Clock_SetPhaseValue(clkPhase)        Sync_Clock_SetPhaseRegister((clkPhase) + 1)
#endif


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define Sync_Clock_CLKEN              (* (reg8 *) Sync_Clock__PM_ACT_CFG)
#define Sync_Clock_CLKEN_PTR          ((reg8 *) Sync_Clock__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define Sync_Clock_CLKSTBY            (* (reg8 *) Sync_Clock__PM_STBY_CFG)
#define Sync_Clock_CLKSTBY_PTR        ((reg8 *) Sync_Clock__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define Sync_Clock_DIV_LSB            (* (reg8 *) Sync_Clock__CFG0)
#define Sync_Clock_DIV_LSB_PTR        ((reg8 *) Sync_Clock__CFG0)
#define Sync_Clock_DIV_PTR            ((reg16 *) Sync_Clock__CFG0)

/* Clock MSB divider configuration register. */
#define Sync_Clock_DIV_MSB            (* (reg8 *) Sync_Clock__CFG1)
#define Sync_Clock_DIV_MSB_PTR        ((reg8 *) Sync_Clock__CFG1)

/* Mode and source configuration register */
#define Sync_Clock_MOD_SRC            (* (reg8 *) Sync_Clock__CFG2)
#define Sync_Clock_MOD_SRC_PTR        ((reg8 *) Sync_Clock__CFG2)

#if defined(Sync_Clock__CFG3)
/* Analog clock phase configuration register */
#define Sync_Clock_PHASE              (* (reg8 *) Sync_Clock__CFG3)
#define Sync_Clock_PHASE_PTR          ((reg8 *) Sync_Clock__CFG3)
#endif


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define Sync_Clock_CLKEN_MASK         Sync_Clock__PM_ACT_MSK
#define Sync_Clock_CLKSTBY_MASK       Sync_Clock__PM_STBY_MSK

/* CFG2 field masks */
#define Sync_Clock_SRC_SEL_MSK        Sync_Clock__CFG2_SRC_SEL_MASK
#define Sync_Clock_MODE_MASK          (~(Sync_Clock_SRC_SEL_MSK))

#if defined(Sync_Clock__CFG3)
/* CFG3 phase mask */
#define Sync_Clock_PHASE_MASK         Sync_Clock__CFG3_PHASE_DLY_MASK
#endif

#endif /* CY_CLOCK_Sync_Clock_H */


/* [] END OF FILE */
