/*******************************************************************************
* File Name: isr_uart.c  
* Version 1.60
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/


#include <CYDEVICE.H>
#include <CYDEVICE_TRM.H>
#include <CYLIB.H>
#include <isr_uart.H>


/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START isr_uart_intc` */
#include "callback.h"
/* `#END` */

#ifndef CYINT_IRQ_BASE
#define CYINT_IRQ_BASE	16
#endif
#ifndef CYINT_VECT_TABLE
#define CYINT_VECT_TABLE    ((cyisraddress **) CYREG_NVIC_VECT_OFFSET)
#endif

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);

/*******************************************************************************
* Function Name: isr_uart_Start
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   void.
*
*
* Return:
*   void.
*
*******************************************************************************/
void isr_uart_Start(void)
{
    /* For all we know the interrupt is active. */
    isr_uart_Disable();

    /* Set the ISR to point to the isr_uart Interrupt. */
    isr_uart_SetVector(isr_uart_Interrupt);

    /* Set the priority. */
    isr_uart_SetPriority(isr_uart_INTC_PRIOR_NUMBER);

    /* Enable it. */
    isr_uart_Enable();
}

/*******************************************************************************
* Function Name: isr_uart_StartEx
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*******************************************************************************/
void isr_uart_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    isr_uart_Disable();

    /* Set the ISR to point to the isr_uart Interrupt. */
    isr_uart_SetVector(address);

    /* Set the priority. */
    isr_uart_SetPriority(isr_uart_INTC_PRIOR_NUMBER);

    /* Enable it. */
    isr_uart_Enable();
}

/*******************************************************************************
* Function Name: isr_uart_Stop
********************************************************************************
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
void isr_uart_Stop(void) 
{
    /* Disable this interrupt. */
    isr_uart_Disable();

    /* Set the ISR to point to the passive one. */
    isr_uart_SetVector(IntDefaultHandler);
}

/*******************************************************************************
* Function Name: isr_uart_Interrupt
********************************************************************************
* Summary:
*   The default Interrupt Service Routine for isr_uart.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
*
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
CY_ISR(isr_uart_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START isr_uart_Interrupt` */
	handle_irq();
    /* `#END` */
}

/*******************************************************************************
* Function Name: isr_uart_SetVector
********************************************************************************
* Summary:
*   Change the ISR vector for the Interrupt. Note calling isr_uart_Start
*   will override any effect this method would have had. To set the vector before
*   the component has been started use isr_uart_StartEx instead.
*
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void isr_uart_SetVector(cyisraddress address) 
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    ramVectorTable[CYINT_IRQ_BASE + isr_uart__INTC_NUMBER] = address;
}

/*******************************************************************************
* Function Name: isr_uart_GetVector
********************************************************************************
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*
*******************************************************************************/
cyisraddress isr_uart_GetVector(void) 
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    return ramVectorTable[CYINT_IRQ_BASE + isr_uart__INTC_NUMBER];
}

/*******************************************************************************
* Function Name: isr_uart_SetPriority
********************************************************************************
* Summary:
*   Sets the Priority of the Interrupt. Note calling isr_uart_Start
*   or isr_uart_StartEx will override any effect this method would have had. 
*	This method should only be called after isr_uart_Start or 
*	isr_uart_StartEx has been called. To set the initial
*	priority for the component use the cydwr file in the tool.
*
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void isr_uart_SetPriority(uint8 priority) 
{
    *isr_uart_INTC_PRIOR = priority << 5;
}

/*******************************************************************************
* Function Name: isr_uart_GetPriority
********************************************************************************
* Summary:
*   Gets the Priority of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
*******************************************************************************/
uint8 isr_uart_GetPriority(void) 
{
    uint8 priority;


    priority = *isr_uart_INTC_PRIOR >> 5;

    return priority;
}

/*******************************************************************************
* Function Name: isr_uart_Enable
********************************************************************************
* Summary:
*   Enables the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void isr_uart_Enable(void) 
{
    /* Enable the general interrupt. */
    *isr_uart_INTC_SET_EN = isr_uart__INTC_MASK;
}

/*******************************************************************************
* Function Name: isr_uart_GetState
********************************************************************************
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   1 if enabled, 0 if disabled.
*
*
*******************************************************************************/
uint8 isr_uart_GetState(void) 
{
    /* Get the state of the general interrupt. */
    return (*isr_uart_INTC_SET_EN & isr_uart__INTC_MASK) ? 1:0;
}

/*******************************************************************************
* Function Name: isr_uart_Disable
********************************************************************************
* Summary:
*   Disables the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void isr_uart_Disable(void) 
{
    /* Disable the general interrupt. */
    *isr_uart_INTC_CLR_EN = isr_uart__INTC_MASK;
}

/*******************************************************************************
* Function Name: isr_uart_SetPending
********************************************************************************
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void isr_uart_SetPending(void) 
{
    *isr_uart_INTC_SET_PD = isr_uart__INTC_MASK;
}

/*******************************************************************************
* Function Name: isr_uart_ClearPending
********************************************************************************
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void isr_uart_ClearPending(void) 
{
    *isr_uart_INTC_CLR_PD = isr_uart__INTC_MASK;
}
