/* ========================================
 *
 * Copyright Hendrik Lipka, 2011
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF Hendrik Lipka.
 *
 * ========================================
*/

#include "device.h"

#include "admscope.h"

#include "stdlib.h"
#include "string.h"

#define DMA_ADC_BYTES_PER_BURST 2
#define DMA_ADC_REQUEST_PER_BURST 1
#define DMA_ADC_SRC_BASE (CYDEV_PERIPH_BASE)
#define DMA_ADC_DST_BASE (CYDEV_SRAM_BASE)

#define DMA_DIG_BYTES_PER_BURST 1
#define DMA_DIG_REQUEST_PER_BURST 1
#define DMA_DIG_SRC_BASE (CYDEV_PERIPH_BASE)
#define DMA_DIG_DST_BASE (CYDEV_SRAM_BASE)

uint8 DMA_ADC1_Chan=0xff;
uint8 DMA_ADC1_TD[16];
int16 *DMA_ADC1_target=NULL;

uint8 DMA_ADC2_Chan=0xff;
uint8 DMA_ADC2_TD[16];
int16 *DMA_ADC2_target=NULL;

uint8 DMA_DIG_Chan=0xff;
uint8 DMA_DIG_TD[16];
uint8 *DMA_DIG_target=NULL;

extern uint32 sampleCount;

uint8 tdCount=0;

void start_dma()
{
	if (NULL!=DMA_ADC1_target)
	{
		free(DMA_ADC1_target);
	}
	if (NULL!=DMA_ADC2_target)
	{
		free(DMA_ADC2_target);
	}
	if (NULL!=DMA_DIG_target)
	{
		free(DMA_DIG_target);
	}
	DMA_ADC1_target=malloc(2*sampleCount+16);
	memset(DMA_ADC1_target,0,2*sampleCount+16);

	DMA_ADC2_target=malloc(2*sampleCount+16);
	memset(DMA_ADC2_target,0,2*sampleCount+16);
	
	DMA_DIG_target=malloc(sampleCount+16);
	memset(DMA_DIG_target,0,sampleCount+16);
	uint8 i;
	// free the old TDs before re-calculating the TD count
	// and set all TDs to invalid
	if (0xFF!=DMA_ADC1_Chan)
	{
		for (i=0;i<tdCount;i++)	
			CyDmaTdFree(DMA_ADC1_TD[i]);
		DMA_ADC1_DmaRelease();
	}
	memset(DMA_ADC1_TD,0xff,16);
	
	if (0xFF!=DMA_ADC2_Chan)
	{
		for (i=0;i<tdCount;i++)	
			CyDmaTdFree(DMA_ADC2_TD[i]);
		DMA_ADC2_DmaRelease();
	}
	memset(DMA_ADC2_TD,0xff,16);

	if (0xFF!=DMA_DIG_Chan)
	{
		for (i=0;i<tdCount;i++)	
			CyDmaTdFree(DMA_DIG_TD[i]);
		DMA_DIG_DmaRelease();
	}
	memset(DMA_DIG_TD,0xff,16);
	
	// one TD for each full 2k block, and an additonal one for the last non-full block
	tdCount=sampleCount/SAMPLE_BLOCK_SIZE+((0==(sampleCount%SAMPLE_BLOCK_SIZE))?0:1); 

	uint16 lastBlockSize=sampleCount%SAMPLE_BLOCK_SIZE;
	if (0==lastBlockSize)
		lastBlockSize=SAMPLE_BLOCK_SIZE;
		
	// Analog1
	DMA_ADC1_Chan = DMA_ADC1_DmaInitialize(DMA_ADC_BYTES_PER_BURST, DMA_ADC_REQUEST_PER_BURST, 
		HI16(DMA_ADC_SRC_BASE), HI16(DMA_ADC_DST_BASE));

	for (i=0;i<tdCount;i++)
	{
		DMA_ADC1_TD[i] = CyDmaTdAllocate();
	}
	for (i=0;i<tdCount;i++)
	{
		if (i==tdCount-1)
			CyDmaTdSetConfiguration(DMA_ADC1_TD[i], lastBlockSize*2, DMA_INVALID_TD, DMA_ADC1__TD_TERMOUT_EN | TD_INC_DST_ADR);
		else
			CyDmaTdSetConfiguration(DMA_ADC1_TD[i], SAMPLE_BLOCK_SIZE*2, DMA_ADC1_TD[i+1], TD_INC_DST_ADR);
		uint32 addr=(uint32)(DMA_ADC1_target)+SAMPLE_BLOCK_SIZE*i*2;
		CyDmaTdSetAddress(DMA_ADC1_TD[i], LO16((uint32)ADC_SAR_1_SAR_WRK0_PTR), LO16((uint32)addr));
	}
	
	CyDmaChSetInitialTd(DMA_ADC1_Chan, DMA_ADC1_TD[0]);
	CyDmaChEnable(DMA_ADC1_Chan, 1);
	
	// Analog2
	DMA_ADC2_Chan = DMA_ADC2_DmaInitialize(DMA_ADC_BYTES_PER_BURST, DMA_ADC_REQUEST_PER_BURST, 
		HI16(DMA_ADC_SRC_BASE), HI16(DMA_ADC_DST_BASE));
	
	for (i=0;i<tdCount;i++)
	{
		DMA_ADC2_TD[i] = CyDmaTdAllocate();
	}
	for (i=0;i<tdCount;i++)
	{
		if (i==tdCount-1)
			CyDmaTdSetConfiguration(DMA_ADC2_TD[i], lastBlockSize*2, DMA_INVALID_TD, TD_INC_DST_ADR);
		else
			CyDmaTdSetConfiguration(DMA_ADC2_TD[i], SAMPLE_BLOCK_SIZE*2, DMA_ADC2_TD[i+1], TD_INC_DST_ADR);
		uint32 addr=(uint32)(DMA_ADC2_target)+SAMPLE_BLOCK_SIZE*i*2;
		CyDmaTdSetAddress(DMA_ADC2_TD[i], LO16((uint32)ADC_SAR_2_SAR_WRK0_PTR), LO16((uint32)addr));
	}
	
	CyDmaChSetInitialTd(DMA_ADC2_Chan, DMA_ADC2_TD[0]);
	CyDmaChEnable(DMA_ADC2_Chan, 1);
	
	// Digital
	DMA_DIG_Chan = DMA_DIG_DmaInitialize(DMA_DIG_BYTES_PER_BURST, DMA_DIG_REQUEST_PER_BURST, 
		HI16(DMA_DIG_SRC_BASE), HI16(DMA_DIG_DST_BASE));

	for (i=0;i<tdCount;i++)
	{
		DMA_DIG_TD[i] = CyDmaTdAllocate();
	}
	for (i=0;i<tdCount;i++)
	{
		if (i==tdCount-1)
			CyDmaTdSetConfiguration(DMA_DIG_TD[i], lastBlockSize, DMA_INVALID_TD, TD_INC_DST_ADR);
		else
			CyDmaTdSetConfiguration(DMA_DIG_TD[i], SAMPLE_BLOCK_SIZE, DMA_DIG_TD[i+1], TD_INC_DST_ADR);
		uint32 addr=(uint32)(DMA_DIG_target)+SAMPLE_BLOCK_SIZE*i;
		CyDmaTdSetAddress(DMA_DIG_TD[i], LO16((uint32)&DigIn_Reg_Status), LO16((uint32)addr));
//		CyDmaTdSetAddress(DMA_DIG_TD[i], LO16((uint32)&DigIn_PS), LO16((uint32)addr));
	}
	
	CyDmaChSetInitialTd(DMA_DIG_Chan, DMA_DIG_TD[0]);
	CyDmaChEnable(DMA_DIG_Chan, 1);
	
}

void stop_dma()
{
	CyDmaChDisable(DMA_ADC1_Chan);
	CyDmaClearPendingDrq(DMA_ADC1_Chan);
	CyDmaChDisable(DMA_ADC2_Chan);
	CyDmaClearPendingDrq(DMA_ADC2_Chan);
	CyDmaChDisable(DMA_DIG_Chan);
	CyDmaClearPendingDrq(DMA_DIG_Chan);
}

/* [] END OF FILE */
