/* ========================================
 *
 * Copyright Hendrik Lipka, 2011
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF Hendrik Lipka.
 *
 * ========================================
*/

#include <device.h>
#include <stdbool.h>
#include "glcd.h"

#define WIDTH 192
#define HEIGHT 128

void send_byte(bool cmd, uint8 dat)
{
	// set write mode
	CyPins_ClearPin(GLCD_Control_RW);
	// set RS according to cmd vs. data
	if(cmd)
		CyPins_SetPin(GLCD_Control_RS);
	else
		CyPins_ClearPin(GLCD_Control_RS);
	// disable		
	CyPins_ClearPin(GLCD_Control_E);
	// select chip
	CyPins_ClearPin(GLCD_Control_CS);
	// write out data
	GLCD_Data_Write(dat);
	// setup time
	CyDelayUs(1);
	// enable
	CyPins_SetPin(GLCD_Control_E);
	// cycle time
	CyDelayUs(1);
	// data is read on falling flank
	CyPins_ClearPin(GLCD_Control_E);
	// wait for settle
	CyDelayUs(1);
	// de-select chip
	CyPins_SetPin(GLCD_Control_CS);
	CyDelayUs(1);
}

void send_cmd(uint8 cmd)
{
	send_byte(true,cmd);
}

void send_data(uint8 dat)
{
	send_byte(false,dat);
}

void glcd_init()
{
	// display on, master, graphics mode
	send_cmd(0);
	send_data(0x32); 
	CyDelayUs(5);
	
	// set horizontal pitch (bits per byte)
	send_cmd(1);
	send_data(0x77); // bytes-1
	CyDelayUs(5);

	// 24 bytes per line
	send_cmd(2);
	send_data((WIDTH/8)-1); 
	CyDelayUs(5);
	
	// 128 lines
	send_cmd(3);
	send_data(HEIGHT-1); 
	CyDelayUs(5);
	
	// display start address=0
	send_cmd(8);
	send_data(0);
	CyDelayUs(5);
	send_cmd(9);
	send_data(0);
	CyDelayUs(5);
	
	CyDelayUs(1000);
}

void set_cursor(uint16 addr)
{
	uint8 addr_low=addr&0xff;
	uint8 addr_high=(addr&0xff00)>>8;
	
	// set cursor address
	send_cmd(10);
	send_data(addr_low);
	CyDelayUs(5);
	send_cmd(11);
	send_data(addr_high);
	CyDelayUs(5);
}

void glcd_clear()
{
	set_cursor(0);
	send_cmd(0x0c);
	int x,y;
	for (y=0;y<HEIGHT;y++)
	{
		for (x=0;x<WIDTH;x++)
		{
			send_data(0);
			CyDelayUs(10);
		}
	}
}

void glcd_set_pixel(uint8 x, uint8 y)
{
	uint16 addr=(x+y*WIDTH)/8; 
	uint8 bit_addr=x&7; // bit address

	set_cursor(addr);
	
	send_cmd(15);
	send_data(bit_addr);
	CyDelayUs(40);
}


/* [] END OF FILE */
