/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/

#include "scope.h"
#include "callback.h"

#include "stdbool.h"

void mark_cursor(int row, int col)
{
	LCD_Position(row,col);
	LCD_PutChar(0);
	LCD_IsReady();
	LCD_Position(row,col);
}

uint8 selected_dig_trg=0;
uint8 dig_mask=0;
uint8 dig_values=0;

void print_dig_state()
{
	int pos;
	for (pos=0;pos<8;pos++)
	{
		LCD_Position(0,4+pos);
		int bitmask=(0x80)>>pos;
		int mask=dig_mask&bitmask;
		int value=dig_values&bitmask;
		if (0==mask)
			LCD_PutChar('X');
		else 
			LCD_PutChar(0==value?'0':'1');
	}
}

void do_ui_dig_trg(bool top_pressed, bool bottom_pressed, uint8 slider, bool init)
{
	if (init)
	{
		LCD_ClearDisplay();
		LCD_IsReady();
		LCD_PrintString("  7          0");
		LCD_IsReady();
		LCD_Position(0,3);
		LCD_PutChar(0);
		LCD_IsReady();
		LCD_Position(0,12);
		LCD_PutChar(2);
		LCD_IsReady();
		LCD_Position(1,4);
		LCD_PutChar(1);
		LCD_IsReady();
		selected_dig_trg=0;
		print_dig_state();
	}
	if (bottom_pressed)
	{
		LCD_Position(1,4+selected_dig_trg);
		LCD_PutChar(' ');
		LCD_IsReady();
		selected_dig_trg=(selected_dig_trg+1)%8;
		LCD_Position(1,4+selected_dig_trg);
		LCD_PutChar(1);
		LCD_IsReady();
	}
	if (top_pressed)
	{
		int bitmask=(0x80)>>selected_dig_trg;
		int mask=dig_mask&bitmask;
		int value=dig_values&bitmask;
		// order is x,0,1
		// current is 'x' -> go to 0
		if (0==mask)
		{
			dig_mask+=bitmask;
			dig_values&=~bitmask; // clean value
		}
		else
		{
			// current is '0'->go to '1'
			if (0==value)
				dig_values+=bitmask;
			else
			{
				// go from '1' to 'x'
				dig_mask-=bitmask;
			}
		}
		print_dig_state();
	}

	LCD_Position(1,4+selected_dig_trg);
}

uint8 selected_ana1_trg=0;
bool ana1_trg=false, ana1_rising=false;
uint8 ana1_level=50;

void print_ana1_trg_state()
{
	LCD_Position(1,1);
	LCD_PrintString(ana1_trg?"yes":"no ");
	LCD_IsReady();
	
	LCD_Position(1,6);
	LCD_PrintString(ana1_rising?"rise":"fall");
	LCD_IsReady();

	LCD_Position(1,12);
	LCD_PrintString("   ");
	LCD_IsReady();
	LCD_Position(1,12);
	LCD_PrintNumber(ana1_level);
	LCD_IsReady();
}

void do_ui_ana1_trg(bool top_pressed, bool bottom_pressed, uint8 slider, bool init)
{
	if (init)
	{
		LCD_ClearDisplay();
		LCD_IsReady();
		LCD_PrintString("trg1 flank level");
		LCD_IsReady();
		mark_cursor(1,0);
		selected_ana1_trg=0;
		print_ana1_trg_state();
	}

	if (bottom_pressed)
	{
		selected_ana1_trg=(selected_ana1_trg+1)%4;
		LCD_Position(1,0);
		LCD_PutChar(' ');
		LCD_IsReady();
		LCD_Position(1,5);
		LCD_PutChar(' ');
		LCD_IsReady();
		LCD_Position(1,11);
		LCD_PutChar(' ');
		LCD_IsReady();
	}
	
	if (top_pressed)
	{
		switch(selected_ana1_trg)
		{
			case 0:
				ana1_trg=!ana1_trg;				
				break;
			case 1:
				ana1_rising=!ana1_rising;
				break;
		}
		print_ana1_trg_state();
	}
	if (0xff!=slider)
	{
		ana1_level=slider;
		print_ana1_trg_state();
	}
	int pos=0;
	if (0==selected_ana1_trg)
	{
		pos=0;
	}
	else if (1==selected_ana1_trg)
	{
		pos=5;
	}
	else if (2==selected_ana1_trg)
	{
		pos=11;
	}
	mark_cursor(1,pos);
}

uint8 calculate_gain_view(uint8 value)
{
	switch(value)
	{
		case 0:
			return 1;
		case 1:
			return 2;
		case 2:
			return 4;
		case 3:
			return 8;
		case 4:
			return 16;
		case 5:
			return 24;
		case 6:
			return 25;
		case 7:
			return 32;
		case 8:
			return 48;
		case 9:
			return 50;
		default:
			return 1;
	}
}

uint8 selected_in1=0;
uint8 ana1_src=0;
uint8 ana1_gain=0;

void print_ana1_in_state()
{
	LCD_Position(1,1);
	LCD_PrintNumber(ana1_src+1);
	LCD_IsReady();
	
	LCD_Position(1,10);
	LCD_PrintString("  ");
	LCD_IsReady();
	LCD_Position(1,10);
	LCD_PrintNumber(calculate_gain_view(ana1_gain));
	LCD_IsReady();
}

void do_ui_ana1_input(bool top_pressed, bool bottom_pressed, uint8 slider, bool init)
{
	if (init)
	{
		LCD_ClearDisplay();
		LCD_IsReady();
		LCD_PrintString(" source1  gain");
		LCD_IsReady();
		print_ana1_in_state();
		mark_cursor(1,0);
		selected_in1=0;
	}

	if (bottom_pressed)
	{
		selected_in1=1-selected_in1;
		if (0==selected_in1)
		{
			LCD_Position(1,9);
			LCD_PutChar(' ');
			LCD_IsReady();
			mark_cursor(1,0);
		}
		else
		{
			LCD_Position(1,0);
			LCD_PutChar(' ');
			LCD_IsReady();
			mark_cursor(1,9);
		}
	}
	
	if (top_pressed)
	{
		if (0==selected_in1)
		{
			ana1_src=(ana1_src+1)%2;
		}
		else
		{
			ana1_gain=(ana1_gain+1)%10;
		}
		print_ana1_in_state();
	}
	LCD_Position(1,selected_in1*9);
}

uint8 selected_ana2_trg=0;
bool ana2_trg=false, ana2_rising=false;
uint8 ana2_level=50;

void print_ana2_trg_state()
{
	LCD_Position(1,1);
	LCD_PrintString(ana2_trg?"yes":"no ");
	LCD_IsReady();
	
	LCD_Position(1,6);
	LCD_PrintString(ana2_rising?"rise":"fall");
	LCD_IsReady();

	LCD_Position(1,12);
	LCD_PrintString("   ");
	LCD_IsReady();
	LCD_Position(1,12);
	LCD_PrintNumber(ana2_level);
	LCD_IsReady();
}

void do_ui_ana2_trg(bool top_pressed, bool bottom_pressed, uint8 slider, bool init)
{
	if (init)
	{
		LCD_ClearDisplay();
		LCD_IsReady();
		LCD_PrintString("trg2 flank level");
		LCD_IsReady();
		print_ana2_trg_state();
		mark_cursor(1,0);
		selected_ana2_trg=0;
	}

	if (bottom_pressed)
	{
		selected_ana2_trg=(selected_ana2_trg+1)%4;
		LCD_Position(1,0);
		LCD_PutChar(' ');
		LCD_IsReady();
		LCD_Position(1,5);
		LCD_PutChar(' ');
		LCD_IsReady();
		LCD_Position(1,11);
		LCD_PutChar(' ');
		LCD_IsReady();
	}

	if (top_pressed)
	{
		switch(selected_ana2_trg)
		{
			case 0:
				ana2_trg=!ana2_trg;				
				break;
			case 1:
				ana2_rising=!ana2_rising;
				break;
		}
		print_ana2_trg_state();
	}
	if (0xff!=slider)
	{
		ana2_level=slider;
		print_ana2_trg_state();
	}
	
	int pos=0;
	if (0==selected_ana2_trg)
	{
		pos=0;
	}
	else if (1==selected_ana2_trg)
	{
		pos=5;
	}
	else if (2==selected_ana2_trg)
	{
		pos=11;
	}
	mark_cursor(1,pos);
}

uint8 selected_in2=0;
uint8 ana2_src=0;
uint8 ana2_gain=0;

void print_ana2_in_state()
{
	LCD_Position(1,1);
	LCD_PrintNumber(ana2_src+1);
	LCD_IsReady();
	
	LCD_Position(1,10);
	LCD_PrintString("  ");
	LCD_IsReady();
	LCD_Position(1,10);
	LCD_PrintNumber(calculate_gain_view(ana2_gain));
	LCD_IsReady();
}

void do_ui_ana2_input(bool top_pressed, bool bottom_pressed, uint8 slider, bool init)
{
	if (init)
	{
		LCD_ClearDisplay();
		LCD_IsReady();
		LCD_PrintString(" source2  gain");
		LCD_IsReady();
		print_ana2_in_state();
		mark_cursor(1,0);
		selected_in2=0;
	}

	if (bottom_pressed)
	{
		selected_in2=1-selected_in2;
		if (0==selected_in2)
		{
			LCD_Position(1,9);
			LCD_PutChar(' ');
			LCD_IsReady();
			mark_cursor(1,0);
		}
		else
		{
			LCD_Position(1,0);
			LCD_PutChar(' ');
			LCD_IsReady();
			mark_cursor(1,9);
		}
	}
	if (top_pressed)
	{
		if (0==selected_in2)
		{
			ana2_src=(ana2_src+1)%2;
		}
		else
		{
			ana2_gain=(ana2_gain+1)%10;
		}
		print_ana2_in_state();
	}
	LCD_Position(1,selected_in2*9);
}

uint8 selected_sample=0;
uint8 sample_depth_sel=0;
uint8 sample_depths[8]={1,2,3,4,6,8};
char* sample_depth_names[8]={"1k","2k","3k","4k","6k","8k"};

uint8 sample_rate_sel=0;
uint32 sample_rates[9]={500000,200000,100000,50000,20000,10000,5000,2000,1000}; // Hz
char* sample_rate_names[9]={"500kHz","200kHz","100kHz","50kHz","20kHz","10kHz","5kHz","2kHz","1kHz"};
char buf[4];

void print_sample_state()
{
	LCD_Position(1,1);
	LCD_PrintString("   ");
	LCD_IsReady();
	LCD_Position(1,1);
	LCD_PrintString(sample_depth_names[sample_depth_sel]);
	LCD_IsReady();
	
	LCD_Position(1,10);
	LCD_PrintString("      ");
	LCD_IsReady();
	LCD_Position(1,10);
	LCD_PrintString(sample_rate_names[sample_rate_sel]);
	LCD_IsReady();

}

void do_ui_sample(bool top_pressed, bool bottom_pressed, uint8 slider, bool init)
{
	if (init)
	{
		LCD_ClearDisplay();
		LCD_IsReady();
		LCD_PrintString(" depth    rate");
		LCD_IsReady();
		print_sample_state();
		mark_cursor(1,0);
		selected_sample=0;
	}

	if (bottom_pressed)
	{
		selected_sample=1-selected_sample;
		if (0==selected_sample)
		{
			LCD_Position(1,9);
			LCD_PutChar(' ');
			LCD_IsReady();
			mark_cursor(1,0);
		}
		else
		{
			LCD_Position(1,0);
			LCD_PutChar(' ');
			LCD_IsReady();
			mark_cursor(1,9);
		}
	}
	if (top_pressed)
	{
		if (0==selected_sample)
		{
			sample_depth_sel=(sample_depth_sel+1)%6;
		}
		else
		{
			sample_rate_sel=(sample_rate_sel+1)%9;
		}
		print_sample_state();
	}

	LCD_Position(1,selected_sample*9);
}

uint8 selected_trg=0;
bool ch_ana1=true, ch_ana2=true, ch_dig=true;

void do_ui_trigger(bool top_pressed, bool bottom_pressed, uint8 slider, bool init)
{
	if (init)
	{
		LCD_ClearDisplay();
		LCD_IsReady();
		LCD_PrintString("a1 a2 dg   start");
		LCD_IsReady();
		
		LCD_Position(1,13);
		LCD_PrintString("go!");
		LCD_IsReady();

		LCD_Position(1,1);
		LCD_PutChar(ch_ana1?'y':'n');
		LCD_IsReady();
		LCD_Position(1,4);
		LCD_PutChar(ch_ana2?'y':'n');
		LCD_IsReady();
		LCD_Position(1,7);
		LCD_PutChar(ch_dig?'y':'n');
		LCD_IsReady();

		mark_cursor(1,0);
		
		selected_trg=0;
	}

	if (bottom_pressed)
	{
		selected_trg=(selected_trg+1)%4;
		LCD_Position(1,0);
		LCD_PutChar(' ');
		LCD_IsReady();
		LCD_Position(1,3);
		LCD_PutChar(' ');
		LCD_IsReady();
		LCD_Position(1,6);
		LCD_PutChar(' ');
		LCD_IsReady();
		LCD_Position(1,11);
		LCD_PutChar(' ');
		LCD_IsReady();
		int pos;
		if (0==selected_trg)
		{
			pos=0;
		}
		else if (1==selected_trg)
		{
			pos=3;
		}
		else if (2==selected_trg)
		{
			pos=6;
		}
		else if (3==selected_trg)
		{
			pos=11;
		}
		mark_cursor(1,pos);
	}
	if (top_pressed)
	{
		if (0==selected_trg)
		{
			ch_ana1=!ch_ana1;
			LCD_Position(1,1);
			LCD_PutChar(ch_ana1?'y':'n');
			LCD_IsReady();
		}
		if (1==selected_trg)
		{
			ch_ana2=!ch_ana2;
			LCD_Position(1,4);
			LCD_PutChar(ch_ana2?'y':'n');
			LCD_IsReady();
		}
		if (2==selected_trg)
		{
			ch_dig=!ch_dig;
			LCD_Position(1,7);
			LCD_PutChar(ch_dig?'y':'n');
			LCD_IsReady();
		}
		if (3==selected_trg)
		{
			LCD_Position(1,3);
			LCD_PrintString("now");
			LCD_IsReady();
			do_arm_local=1;
		}
	}
}

void parseTriggerDataLocal()
{
	sendChannel0=1;
	sendChannel1=1;
	sendChannel2=1;
	sendChannel3=0; // fourth channel is off by default
	
	triggerActive1=0;
	triggerActive2=0;
	triggerRising1=0;
	triggerRising2=0;
	
	triggerValuesDig=dig_values;
	triggerMaskDig=dig_mask;
	
	channelMux1=0;
	channelMux2=0;
	
	triggerLevel1=128;
	triggerLevel2=128;

	if (ch_ana1)
		sendChannel1=1;
	else
		sendChannel1=0;

	if (ch_ana2)
		sendChannel2=1;
	else
		sendChannel2=0;
	
	if (ch_dig)
		sendChannel3=1;
	else
		sendChannel3=0;
		
	divider=(( 1.0 * 100000000 )/(sample_rates[sample_rate_sel]))-1;
	
	sampleCount=sample_depths[sample_depth_sel]*1024;
	
	triggerLevel1=((1.0*ana1_level)/100)*255;
	triggerRising1=ana1_rising?1:0;
	triggerActive1=ana1_trg?1:0;
	channelMux1=ana1_src;
	channelGain1=ana1_gain;
	
	triggerLevel2=((1.0*ana2_level)/100)*255;
	triggerRising2=ana2_rising?1:0;
	triggerActive2=ana2_trg?1:0;
	channelMux2=ana2_src;
	channelGain2=ana2_gain;

}

/* [] END OF FILE */
