/* ========================================
 *
 * Copyright Hendrik Lipka, 2011
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF Hendrik Lipka
 *
 * ========================================
*/

#include <CYLIB.H>

#define CHANNELS (3)

#include "UART.h"
#include "callback.h"

// received config values
uint8 trigger_mask[4]={0};
uint8 trigger_values[4]={0};
uint8 trigger_conf[4]={0};
uint8 divider_conf[4]={0};
uint8 delay_conf[4]={0};
uint8 trigger_flags[4]={0};

uint8 send_mask=0;
uint8 send_values=0;
uint8 send_conf=0;
uint8 send_div=0;
uint8 send_delay=0;
uint8 send_flags=0;

uint8 read_buf[4]={0};

uint8 count=0;

void readData()
{
	int i;
	for (i=0;i<4;i++)
	{
		while (0==(UART_RX_STS_FIFO_NOTEMPTY & UART_ReadRxStatus())); // wait for a byte to arrive
		read_buf[i]=UART_ReadRxData();
	}
}


char* name="admScope 0.1";
char* version="v0.1";

void sendLong(uint32 value)
{
	uint32 dat=value;
	uint8* datp=(uint8*)&dat;
	UART_PutChar(datp[3]);
	UART_PutChar(datp[2]);
	UART_PutChar(datp[1]);
	UART_PutChar(datp[0]);
}

void handle_irq()
{
	// nothing to do
	if (0==(UART_RX_STS_FIFO_NOTEMPTY & UART_ReadRxStatus()))
		return;
		
	uint8 data= UART_ReadRxData();

	if (0==data)
	{
		do_transfer=1;
		do_arm_client=0;
		send_flags=0;
		send_mask=0;
		send_values=0;
		send_div=0;
		send_conf=0;
		send_delay=0;

		// do reset
		do_reset=1;
	}
	else if (1==data)
	{
		// arm trigger
		do_arm_client=1;
	}
	else if (2==data)
	{
		// ID
		UART_PutString("1ALS");
	}
	else if (4==data)
	{
		// metadata
		// name
		UART_PutChar(0x01);
		UART_PutString(name);
		UART_PutChar(0x00);

		// FPGA version
		UART_PutChar(0x02);
		UART_PutString(version);
		UART_PutChar(0x00);

		// firmware version
		UART_PutChar(0x03);
		UART_PutString(version);
		UART_PutChar(0x00);

		// number of probes
		UART_PutChar(0x40);
		UART_PutChar(8*CHANNELS);

		// protocol version
		UART_PutChar(0x41);
		UART_PutChar(0x02);

		// probes
		UART_PutChar(0x20);
		sendLong(8*CHANNELS);

		// sample memory
		UART_PutChar(0x21);
		sendLong(0x0400*12); // 12k sample depth

		// dynamic memory
		UART_PutChar(0x22);
		sendLong(0x0400*48); // 48k maximum

		// sample rate (Hz)
		UART_PutChar(0x23);
		sendLong(1000000);

		// protocol
		UART_PutChar(0x24);
		sendLong(0x2);

		UART_PutChar(0x00);
	}
	else if (0x11==data)
	{
		// XON
		do_transfer=0;
	}
	else if (0x13==data)
	{
		// XOFF
		do_transfer=1;
	}
	else if (0xc0==data || 0xc4==data || 0xc8==data || 0xcc==data)
	{
		// set trigger mask
		readData();
		if (0xc0==data)
		{
			memcpy(trigger_mask, read_buf,4);
			send_mask=1;
		}
	}
	else if (0xc1==data || 0xc5==data || 0xc9==data || 0xcd==data)
	{
		// set trigger values
		readData();
		if (0xc1==data)
		{
			memcpy(trigger_values, read_buf,4);
			send_values=1;
		}
	}
	else if (0xc2==data || 0xc6==data || 0xca==data || 0xce==data)
	{
		// set trigger config
		readData();
		if (0xc2==data)
		{
			memcpy(trigger_conf, read_buf,4);
			send_conf=1;
		}
	}
	else if (0x80==data)
	{
		// set divider
		readData();
		memcpy(divider_conf, read_buf,4);
		send_div=1;
	}
	else if (0x81==data)
	{
		// set read and delay count
		readData();
		memcpy(delay_conf, read_buf,4);
		send_delay=1;
	}
	else if (0x82==data)
	{
		// set flags
		readData();
		memcpy(trigger_flags, read_buf,4);
		send_flags=1;
	}
/* to clear the interrrupts*/
	UART_GetRxInterruptSource();    
}
/* [] END OF FILE */
