/* ========================================
 *
 * Copyright Hendrik Lipka, 2011
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF Hendrik Lipka
 *
 * ========================================
*/

#include <device.h>
#include <stdbool.h>

#include "admscope.h"
#include "dma.h"
#include "client_data.h"
#include "dds.h"
#include "glcd.h"
#include "ui.h"

// flags for talking with the ISRs
uint8 do_transfer=1;
uint8 do_reset=0;
uint8 do_arm_client=0;
uint8 do_arm_local=0;
uint8 run_trigger=0;


void reset()
{
	do_reset=0;

	stop_dma();
	
	run_trigger=0;
}


void waitForTrigger()
{
	while(0==run_trigger);
}

void sendByte(uint8 byte)
{
	while (0==do_transfer);
	UART_PutChar(byte);
}

void init_hw()
{
	glcd_init();
	glcd_clear();
	CyDelay(10);
	int i;
	for (i=0;i<128;i++)
	{
		glcd_set_pixel(i,i);
		glcd_set_pixel(i,127-i);

		glcd_set_pixel(i,0);
		glcd_set_pixel(i,64);
		glcd_set_pixel(i,127);
		glcd_set_pixel(127,i);
		glcd_set_pixel(64,i);
		glcd_set_pixel(0,i);
	}

	init_dds();

	CYGlobalIntEnable;
	init_ui();

	init_scope();


	// start ISR handlers
	isr_uart_Start();
	isr_trigger_Start();

	UART_Start();
	
	
}

void transfer_client()
{
	do_transfer=1;
	int i=0;
	for (i=0;i<sampleCount+8;i++)
	{
		if (1==sendChannel0)
			sendByte(DMA_ADC1_target[i]);
		if (1==sendChannel1)
			sendByte(DMA_ADC2_target[i]);
		if (1==sendChannel2)
			sendByte(DMA_DIG_target[i]);
		// if the fourth channel has been enable, send empty data
		if (1==sendChannel3)
			sendByte(0);
	}
}

void draw_pixel(uint8 x, uint8 y, uint8 last_y)
{
	if (y!=last_y && 0xff!=last_y)
	{
		int pos;
		if (y<last_y)
		{
			for (pos=y;pos<last_y;pos++)
				glcd_set_pixel(x,pos);
		}
		else
		{
			for (pos=last_y;pos<y;pos++)
				glcd_set_pixel(x,pos);
		}
	}
}

void draw_local()
{
	int bytes_per_dot=sampleCount/DOTS;
	int x,pos;
	int last_y1=0xff;
	int last_y2=0xff;
	int last_y3[8]={0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff};
	for (x=0;x<DOTS;x++)
	{
		int ofs=x*bytes_per_dot;
		bool first=true;
		for (pos=0;pos<bytes_per_dot;pos++)
		{
			int byte=ofs+pos;
			if (1==sendChannel0)
			{
				int y1=(DMA_ADC1_target[byte]>>4)/8;
				if (first)
					glcd_set_pixel(x,y1);
				draw_pixel(x,y1,last_y1);
				last_y1=y1;
			}
			if (1==sendChannel1)
			{
				int y2=((DMA_ADC2_target[byte]>>4)/8)+40;
				if (first)
					glcd_set_pixel(x,y2);
				draw_pixel(x,y2,last_y2);
				last_y2=y2;
			}
			if (1==sendChannel2)
			{
				int y3=DMA_DIG_target[byte];
				int bitnum;
				for (bitnum=0;bitnum<8;bitnum++)
				{
					int bitmask=1<<bitnum;
					int value=1-((y3&bitmask)>>bitnum); // flip bit, since the GLCD starts from the top
					int ypos=3*value+80+bitnum*5; // 5 pixels per bit, each sample is 4 bits high
					if (first)
						glcd_set_pixel(x,ypos);
					draw_pixel(x,ypos,last_y3[bitnum]);
					last_y3[bitnum]=ypos;
				}
			}
			first=false;
		}
	}
}

void main()
{
	// clear trigger
	run_trigger=0;
	Reg_TriggerReset_Write(1);

	init_hw();
	
	CyDelay(10U); // msec
	
    for(;;)
    {
		bool is_local=false;
		// wait for arming the trigger
		while (0==do_arm_client && 0==do_arm_local)
		{
			if (1==do_reset)
				reset();
			do_ui();
		}

		// setup trigger
		LCD_ClearDisplay();
		LCD_IsReady();

		if (1==do_arm_client)
		{
			parseTriggerDataClient();
		}
		else
		{
			glcd_clear();
			parseTriggerDataLocal();
			is_local=true;
		}
		do_arm_client=0;
		do_arm_local=0;
		
		LCD_Position(0u,0u);   
		LCD_PrintString("armed");	
		LCD_IsReady();

		// start trigger
		startTrigger();
		
		// wait for trigger to be activated
		waitForTrigger();
		Reg_TriggerReset_Write(5);

		stop_dma();

		LCD_Position(0u,5u);   
		LCD_PrintString(">trig");	
		LCD_IsReady();
		
		if (is_local)
		{
			draw_local();
			LCD_Position(0u,10u);   
			LCD_PrintString(">done ");	
			LCD_IsReady();
			reset_ui();
		}
		else
		{
			transfer_client();

			LCD_Position(0u,10u);   
			LCD_PrintString(">trans");	
			LCD_IsReady();
		}		
		// de-init
		reset();
		
		do_arm_client=0;
		do_arm_local=0;
		
		// and again...
    }
}

/* [] END OF FILE */
