/* ========================================
 *
 * Copyright Hendrik Lipka, 2011
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF Hendrik Lipka.
 *
 * ========================================
*/

#include <device.h>
#include <stdbool.h>

uint8 topBtn=0;
uint8 bottomBtn=0;
uint8 nextBtn=0;
uint8 prevBtn=0;

uint8 sliderPos=0xff;

uint8 topState=0;
uint8 bottomState=0;

int current_ui=-1;

void do_ui_waveform(bool top_pressed, bool bottom_pressed, uint8 slider, bool init);
void do_ui_wavefreq(bool top_pressed, bool bottom_pressed, uint8 slider, bool init);
void do_ui_dig_trg(bool top_pressed, bool bottom_pressed, uint8 slider, bool init);
void do_ui_ana1_trg(bool top_pressed, bool bottom_pressed, uint8 slider, bool init);
void do_ui_ana1_input(bool top_pressed, bool bottom_pressed, uint8 slider, bool init);
void do_ui_ana2_trg(bool top_pressed, bool bottom_pressed, uint8 slider, bool init);
void do_ui_ana2_input(bool top_pressed, bool bottom_pressed, uint8 slider, bool init);
void do_ui_sample(bool top_pressed, bool bottom_pressed, uint8 slider, bool init);
void do_ui_trigger(bool top_pressed, bool bottom_pressed, uint8 slider, bool init);

#define NUM_UI 9

typedef void (*uiPtr)(bool,bool,uint8,bool);

uiPtr ui_calls[NUM_UI]=
{
	&do_ui_waveform,
	&do_ui_wavefreq,
	&do_ui_dig_trg,
	&do_ui_ana1_trg,
	&do_ui_ana1_input,
	&do_ui_ana2_trg,
	&do_ui_ana2_input,
	&do_ui_sample,
	&do_ui_trigger
};

void init_ui()
{
	/* Initializes the LCD. */
    LCD_Start();
	LCD_ClearDisplay();
	LCD_IsReady();
	LCD_WriteControl(LCD_CURSOR_WINK);
	LCD_IsReady();

	Reg_ResetMenuNext_Write(0);
	Reg_ResetMenuNext_Write(1);
	Reg_ResetMenuNext_Write(0);

	Reg_ResetMenuPrev_Write(0);
	Reg_ResetMenuPrev_Write(1);
	Reg_ResetMenuPrev_Write(0);

	Clock_Button_Start();

	// enable input device
	CapSense_Start();
    CapSense_InitializeAllBaselines();
    CapSense_ScanEnabledWidgets();

	CapSense_EnableWidget(CapSense_SLIDER__LS);
	CapSense_EnableWidget(CapSense_BOTTOM__BTN);
	CapSense_EnableWidget(CapSense_TOP__BTN);
}

void reset_ui()
{
	current_ui=-1;
}

void do_ui()
{
	bool do_init=false;
	if (-1==current_ui)
	{
		do_init=true;
		current_ui=0;
	}
	if (0==nextBtn)
	{
		if (0==Reg_MenuNextBtn_Read())
		{
			current_ui=(current_ui+1)%NUM_UI;
			Reg_ResetMenuNext_Write(0);
			Reg_ResetMenuNext_Write(1);
			Reg_ResetMenuNext_Write(0);
			nextBtn=1;
			do_init=true;
		}
	}
	else
	{
		if (1==Reg_MenuNextBtn_Read())
			nextBtn=0;	
	}

	if (0==prevBtn)
	{
		if (0==Reg_MenuPrevBtn_Read())
		{
			current_ui=(current_ui-1);
			if (-1==current_ui)
			{
				current_ui=NUM_UI-1;
			}
			Reg_ResetMenuPrev_Write(0);
			Reg_ResetMenuPrev_Write(1);
			Reg_ResetMenuPrev_Write(0);
			prevBtn=1;
			do_init=true;
		}
	}
	else
	{
		if (1==Reg_MenuPrevBtn_Read())
			prevBtn=0;	
	}
	// check wether we have button input
    if(!CapSense_IsBusy())
    {
        CapSense_UpdateEnabledBaselines();
        CapSense_ScanEnabledWidgets();
		topBtn=CapSense_CheckIsWidgetActive(CapSense_TOP__BTN);
	    bottomBtn=CapSense_CheckIsWidgetActive(CapSense_BOTTOM__BTN);
		sliderPos=CapSense_GetCentroidPos(CapSense_SLIDER__LS);
	}

	bool topPressed=false;
	bool bottomPressed=false;
	uint8 sliderVal=0xff;
	
	// has the wave form changed?
	if (0==topState)
	{
		if (1==topBtn)
		{
			topPressed=true;
			topState=1;
		}
	}
	else
	{
		if (0==topBtn)
		{
			topState=0;
		}
	}

	// has the frequency source changed?
	if (0==bottomState)
	{
		if (1==bottomBtn)
		{
			bottomPressed=true;
			bottomState=1;
		}
	}
	else
	{
		if (0==bottomBtn)
		{
			bottomState=0;
		}
	}

	// does the user want to change the frequency?
	if (0xff!=sliderPos)
	{
		sliderVal=sliderPos;
	}
	ui_calls[current_ui](topPressed, bottomPressed,sliderVal,do_init);
	CyDelay(10);	
}


/* [] END OF FILE */
